@@ -4,6 +4,8 @@ import polars as pl
 import gzip
 from cameo_claw.functional import it_mp_f
 from cameo_claw.net import requests_get
+import warnings
+warnings.filterwarnings("ignore")
 
 
 def a_distinct(url, target_directory, lst_distinct_column):
